@@ -38,13 +38,12 @@ CONTAINS
   !! OUTPUT:
   !! @param in
   !---------------------------------------------------------------------
-  SUBROUTINE init(in,unit)
+  SUBROUTINE init(in)
     USE types
     USE export
     USE getopt_m
 
     TYPE(SIMULATION_STRUC), INTENT(OUT) :: in
-    INTEGER, OPTIONAL, INTENT(INOUT) :: unit
 
     CHARACTER :: ch
     CHARACTER(256) :: dataline
@@ -53,21 +52,14 @@ CONTAINS
     CHARACTER(3) :: digit
     CHARACTER(4) :: digit4
 #endif
-    INTEGER :: iunit
+    INTEGER :: iunit,noptions
 !$  INTEGER :: omp_get_num_procs,omp_get_max_threads
     REAL*8 :: dummy,dum1,dum2
     REAL*8 :: minlength,minwidth
-    TYPE(OPTION_S) :: opts(12)
+    TYPE(OPTION_S) :: opts(13)
 
     INTEGER :: k,iostatus,i,e
 
-    ! default is standard input
-    IF (.NOT. PRESENT(unit)) THEN
-       iunit=5
-    ELSE
-       iunit=unit
-    END IF
-
     ! parse the command line for options
     opts( 1)=OPTION_S("no-proj-output",.FALSE.,CHAR(20))
     opts( 2)=OPTION_S("no-relax-output",.FALSE.,CHAR(21))
@@ -76,12 +68,14 @@ CONTAINS
     opts( 5)=OPTION_S("no-grd-output",.FALSE.,CHAR(24))
     opts( 6)=OPTION_S("no-xyz-output",.FALSE.,CHAR(25))
     opts( 7)=OPTION_S("no-stress-output",.FALSE.,CHAR(26))
-    opts( 8)=OPTION_S("with-stress-output",.FALSE.,CHAR(27))
-    opts( 9)=OPTION_S("with-vtk-output",.FALSE.,CHAR(28))
-    opts(10)=OPTION_S("with-vtk-relax-output",.FALSE.,CHAR(29))
-    opts(11)=OPTION_S("dry-run",.FALSE.,CHAR(30))
-    opts(12)=OPTION_S("help",.FALSE.,'h')
+    opts( 8)=OPTION_S("version",.FALSE.,CHAR(27))
+    opts( 9)=OPTION_S("with-stress-output",.FALSE.,CHAR(28))
+    opts(10)=OPTION_S("with-vtk-output",.FALSE.,CHAR(29))
+    opts(11)=OPTION_S("with-vtk-relax-output",.FALSE.,CHAR(30))
+    opts(12)=OPTION_S("dry-run",.FALSE.,CHAR(31))
+    opts(13)=OPTION_S("help",.FALSE.,'h')
 
+    noptions=0;
     DO
        ch=getopt("h",opts)
        SELECT CASE(ch)
@@ -106,18 +100,21 @@ CONTAINS
           ! option no-xyz-output
           in%isoutputxyz=.FALSE.
        CASE(CHAR(26))
-          ! option stress output
+          ! option no-stress-output
           in%isoutputstress=.FALSE.
        CASE(CHAR(27))
-          ! option dry-run
-          in%isoutputstress=.TRUE.
+          ! option version
+          in%isversion=.TRUE.
        CASE(CHAR(28))
-          ! option with-output-vtk
-          in%isoutputvtk=.TRUE.
+          ! option with-stress-output
+          in%isoutputstress=.TRUE.
        CASE(CHAR(29))
-          ! option with-output-vtk-relax
-          in%isoutputvtkrelax=.TRUE.
+          ! option with-vtk-output
+          in%isoutputvtk=.TRUE.
        CASE(CHAR(30))
+          ! option with-vtk-relax-output
+          in%isoutputvtkrelax=.TRUE.
+       CASE(CHAR(31))
           ! option dry-run
           in%isdryrun=.TRUE.
        CASE('h')
@@ -132,8 +129,14 @@ CONTAINS
           WRITE_DEBUG_INFO
           STOP 3
        END SELECT
+       noptions=noptions+1
     END DO
 
+    IF (in%isversion) THEN
+       PRINT '("relax version 1.0.5, compiled on ",a)', __DATE__
+       PRINT '("")'
+       RETURN
+    END IF
     IF (in%ishelp) THEN
        PRINT '("usage:")'
        PRINT '("relax [-h] [--dry-run] [--help] [--no-grd-output] [--no-proj-output]")' 
@@ -151,6 +154,7 @@ CONTAINS
        PRINT '("   --no-txt-output         cancel output in text format")'
        PRINT '("   --no-vtk-output         cancel output in Paraview VTK format")'
        PRINT '("   --no-xyz-output         cancel output in GMT xyz format")'
+       PRINT '("   --version               print version number and exit")'
        PRINT '("   --with-stress-output    export stress tensor")'
        PRINT '("   --with-vtk-output       export output in Paraview VTK format")'
        PRINT '("   --with-vtk-relax-output export relaxation to VTK format")'
@@ -159,6 +163,9 @@ CONTAINS
        PRINT '("   Evaluates the deformation due to fault slip, surface loading")'
        PRINT '("   or inflation and the time series of postseismic relaxation")'
        PRINT '("   that follows due to fault creep or viscoelastic flow.")'
+       PRINT '("")'
+       PRINT '("see also: ""man relax""")'
+       PRINT '("")'
        RETURN
     END IF
     PRINT 2000
@@ -222,6 +229,15 @@ CONTAINS
 #endif
     PRINT 2000
 
+    IF (noptions .LT. COMMAND_ARGUMENT_COUNT()) THEN
+       iunit=25
+       CALL GET_COMMAND_ARGUMENT(noptions+1,filename)
+       OPEN (UNIT=iunit,FILE=filename,IOSTAT=iostatus)
+    ELSE
+       ! default is standard input
+       iunit=5
+    END IF
+
     PRINT '(a)', "grid dimension (sx1,sx2,sx3)"
     CALL getdata(iunit,dataline)
     READ (dataline,*) in%sx1,in%sx2,in%sx3
@@ -818,6 +834,7 @@ CONTAINS
 
              ALLOCATE(in%n(k)%patch(in%n(k)%px2,in%n(k)%px3),STAT=iostatus)
              IF (iostatus>0) STOP "could not allocate the fault patches"
+             in%n(k)%patch(:,:)=SLIPPATCH_STRUCT(0,0,0,0,0,0,0,0,0,0,0,0,TENSOR(0,0,0,0,0,0))
 
 #ifdef VTK
              ! export the afterslip segment in VTK format
@@ -859,6 +876,7 @@ CONTAINS
                in%inter%s(k)%x,in%inter%s(k)%y,in%inter%s(k)%z, &
                in%inter%s(k)%length,in%inter%s(k)%width, &
                in%inter%s(k)%strike,in%inter%s(k)%dip,in%inter%s(k)%rake
+          in%inter%s(k)%opening=0
 
           ! copy the input format for display
           in%inter%sc(k)=in%inter%s(k)
@@ -1023,6 +1041,7 @@ CONTAINS
                   in%events(e)%s(k)%length,in%events(e)%s(k)%width, &
                   in%events(e)%s(k)%strike,in%events(e)%s(k)%dip,in%events(e)%s(k)%rake, &
                   in%events(e)%s(k)%beta
+             in%events(e)%s(k)%opening=0
 
              SELECT CASE(iostatus)
              CASE (1:)
@@ -1223,7 +1242,7 @@ CONTAINS
                STAT=iostatus)
           IF (iostatus>0) STOP "could not allocate the load list"
           PRINT 2000
-          PRINT '(a)',"t3 in units of force/surface/rigidity, positive down"
+          PRINT '(a)',"t3 in units of force/surface, positive down"
           PRINT '(a)',"T>0 for t3 sin(2pi/T+phi), T<=0 for t3 H(t)"
           PRINT '(a)',"no.       xs       ys   length    width       t3        T      phi"
           PRINT 2000
