@@ -1,5 +1,5 @@
 !-----------------------------------------------------------------------
-! Copyright 2007-2012, Sylvain Barbot
+! Copyright 2007-2013, Sylvain Barbot
 !
 ! This file is part of RELAX
 !
@@ -176,6 +176,7 @@
   !!              and allow scaling of computed time steps.        <br>
   !! (04-26-11) - include command-line arguments
   !! (11-04-11) - compatible with gfortran                         <br>
+  !! (07-25-13) - include cylindrical and spherical ductile zones  <br>
   !!
   !! \todo 
   !!   - homogenize VTK output so that geometry of events match event index
@@ -187,6 +188,7 @@
   !!   - check the fully-relaxed afterslip for uniform stress change
   !!   - include topography of parameter interface
   !!   - export afterslip output in VTK legacy format (binary)
+  !!   - export ductile zones for cylindrical and spherical geometries
   !------------------------------------------------------------------------
 PROGRAM relax
 
@@ -226,7 +228,7 @@ PROGRAM relax
   REAL*4, DIMENSION(:,:), ALLOCATABLE :: t1,t2,t3
   REAL*4, DIMENSION(:,:,:), ALLOCATABLE :: inter1,inter2,inter3
   TYPE(TENSOR), DIMENSION(:,:,:), ALLOCATABLE :: tau,sig,moment
-  
+
 #ifdef FFTW3_THREADS
   CALL sfftw_init_threads(iret)
 #ifdef _OPENMP
@@ -244,7 +246,7 @@ PROGRAM relax
   IF (in%isdryrun) THEN
      PRINT '("dry run: abort calculation")'
   END IF
-  IF (in%isdryrun .OR. in%ishelp) THEN
+  IF (in%isdryrun .OR. in%ishelp .OR. in%isversion) THEN
      ! exit program
      GOTO 100
   END IF
@@ -270,6 +272,7 @@ PROGRAM relax
   IF (in%isoutputrelax) THEN
      ALLOCATE(inter1(in%sx1+2,in%sx2,2),inter2(in%sx1+2,in%sx2,2),inter3(in%sx1+2,in%sx2,2),STAT=iostatus)
      IF (iostatus>0) STOP "could not allocate memory for postseismic displacement"
+     inter1=0;inter2=0;inter3=0;
   END IF
 
   v1=0;v2=0;v3=0;u1=0;u2=0;u3=0;gamma=0;t1=0;t2=0;t3=0
@@ -332,7 +335,7 @@ PROGRAM relax
                          in%dx1,in%dx2,in%dx3,in%sx1,in%sx2,in%sx3/2,in%wdir,0)
   
   ! export equivalent body forces
-  IF (isoutput(in%skip,t,i,in%odt,oi,in%events(e)%time)) THEN
+  IF (isoutput(in%skip,t,0,in%odt,oi,in%events(e)%time)) THEN
 #ifdef GRD_EQBF
      IF (in%isoutputgrd) THEN
         CALL exportgrd(v1,v2,v3,in%sx1,in%sx2,in%sx3/2, &
@@ -645,7 +648,7 @@ PROGRAM relax
      CALL equivalentbodyforce(moment,in%dx1,in%dx2,in%dx3,in%sx1,in%sx2,in%sx3/2,v1,v2,v3,t1,t2,t3)
 
      ! add time-dependent surface loads
-     CALL traction(in%mu,in%events(e),in%sx1,in%sx2,in%dx1,in%dx2,t,Dt,t3,rate=.true.)
+     CALL traction(in%mu,in%events(e),in%sx1,in%sx2,in%dx1,in%dx2,t,Dt,t3,rate=.TRUE.)
 
      ! export equivalent body forces
      IF (isoutput(in%skip,t,i,in%odt,oi,in%events(e)%time)) THEN
@@ -772,7 +775,7 @@ PROGRAM relax
            END IF
         END IF
 #endif
-        !CALL exporteigenstrain(gamma,in%nop,in%op,in%x0,in%y0,in%dx1,in%dx2,in%dx3,in%sx1,in%sx2,in%sx3/2,in%wdir,oi)
+        CALL exporteigenstrain(gamma,in%nop,in%op,in%x0,in%y0,in%dx1,in%dx2,in%dx3,in%sx1,in%sx2,in%sx3/2,in%wdir,oi)
 #ifdef GRD
         IF (in%isoutputgrd) THEN
            IF (in%isoutputrelax) THEN
